==> spark-3.2.4.tgz: spark-3.2.4/sql/catalyst/src/main/java/org/apache/spark/sql/connector/expressions/aggregate/Aggregation.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.spark.sql.connector.expressions.aggregate;

import java.io.Serializable;

import org.apache.spark.annotation.Evolving;
import org.apache.spark.sql.connector.expressions.NamedReference;

/**
 * Aggregation in SQL statement.
 *
 * @since 3.2.0
 */
@Evolving
public final class Aggregation implements Serializable {
  private final AggregateFunc[] aggregateExpressions;
  private final NamedReference[] groupByColumns;

  public Aggregation(AggregateFunc[] aggregateExpressions, NamedReference[] groupByColumns) {
    this.aggregateExpressions = aggregateExpressions;
    this.groupByColumns = groupByColumns;
  }

  public AggregateFunc[] aggregateExpressions() { return aggregateExpressions; }

  public NamedReference[] groupByColumns() { return groupByColumns; }
}

==> spark-3.5.3.tgz: spark-3.5.3/sql/catalyst/src/main/java/org/apache/spark/sql/connector/expressions/aggregate/Aggregation.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.spark.sql.connector.expressions.aggregate;

import java.io.Serializable;

import org.apache.spark.annotation.Evolving;
import org.apache.spark.sql.connector.expressions.Expression;

/**
 * Aggregation in SQL statement.
 *
 * @since 3.2.0
 */
@Evolving
public final class Aggregation implements Serializable {
  private final AggregateFunc[] aggregateExpressions;
  private final Expression[] groupByExpressions;

  public Aggregation(AggregateFunc[] aggregateExpressions, Expression[] groupByExpressions) {
    this.aggregateExpressions = aggregateExpressions;
    this.groupByExpressions = groupByExpressions;
  }

  public AggregateFunc[] aggregateExpressions() { return aggregateExpressions; }

  public Expression[] groupByExpressions() { return groupByExpressions; }
}
